DBENGINE = 'django.db.backends.sqlite3'
DBHOST = '127.0.0.1'
DBPORT = ''
DBUSER = ''
DBPASS = ''
DBNAME = 'django_backstage.sq3'

DATABASES = {}
DATABASES['default'] = {
    'NAME': DBNAME,
    'ENGINE': DBENGINE,
    'HOST': DBHOST,
    'PORT': DBPORT,
    'USER': DBUSER,
    'PASSWORD': DBPASS
}

DEFAULT_DB_ALIAS='default'
DEFAULT_DB = DATABASES['default']



from django.db import models
import django.contrib.sites.models


class BackstageSite(models.Model):
    django_site = models.ForeignKey(django.contrib.sites.models.Site)
    gunicorn_port = models.IntegerField(default=0)
    uwsgi_port = models.IntegerField(default=0)
    hostnames = models.TextField(default='')
    active = models.BooleanField(default=True)

    class Meta():
        db_table = 'backstage_project'


DEBUG=False
TEMPLATE_DEBUG=DEBUG

# Store these package names here as they may change in the future since
# at the moment we are using custom forks of them.
PACKAGE_NAME_FILEBROWSER = "filebrowser_safe"
PACKAGE_NAME_GRAPPELLI = "grappelli_safe"

# Whether a user's session cookie expires when the Web browser is closed.
SESSION_EXPIRE_AT_BROWSER_CLOSE = True






from django.http import HttpResponse,HttpResponseRedirect,HttpResponsePermanentRedirect,Http404
from django.db import models
from django.shortcuts import render_to_response,redirect
from django.template import loader, Context, RequestContext


def index(request,**kwargs):
    return render_to_response('index.html')



from setuptools import setup, find_packages

setup(
    name='django_backstage',
    version='0.0.17',
    description='Django project and site deployment using uWSGI, nginx, etc.',
    author='MiddleFork',
    author_email='walker@mfgis.com',
    packages=find_packages(),
    install_requires=[
        "setuptools_git >= 0.3",
    ],
    entry_points = {
      'console_scripts':
            'backstage_project = backstage.project.new_projectx'
    }
)



from django.http import Http404,HttpResponse
from django.template import loader, Context, RequestContext
from django.shortcuts import render_to_response as r2r


def get_context(request, obj):
    context = RequestContext(request, {'obj': obj, })
    instance = RequestContext(request)
    return context, instance


def render_context(request, obj, template):
    if repr(obj).split(' ')[1] == 'NullObj':
        raise Http404
    try:
        context = RequestContext(request, {'obj': obj, })
        instance = RequestContext(request)
        return r2r(template, context, context_instance=instance)
    except:
        raise


        





#!/usr/bin/python
"""This is the overall settings module for a single Backstage Project instance
 It will import settings from the Backstage package, and may over-ride them.
 In turn, each Backstage Site instance will import these settings, and may over-ride them."""
#
#
#### DO NOT EDIT THIS FILE ####
#
#
import os
import sys

#Assume that 'manage.py' and 'settings.py' are siblings at the root of the Backstage Project instance
PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))
PROJECT_PATH, PROJECT_DIRNAME = os.path.split(PROJECT_ROOT)
PROJECT_NAME = PROJECT_DIRNAME
ROOT_URLCONF = "%s.project.urls" % PROJECT_NAME

PROJECT_NAME in sys.path or sys.path.append(PROJECT_NAME)
PROJECT_PATH in sys.path or sys.path.append(PROJECT_PATH)

#Here, we import all the backstage default settings, django default settings, etc...
from backstage.settings.settings import *

###Here, we extend and over-ride them....

#Extend INSTALLED_APPS
INSTALLED_APPS = list(INSTALLED_APPS)
PROJECT_NAME in INSTALLED_APPS or INSTALLED_APPS.insert(0,PROJECT_NAME)
project_app = '%s.project' % PROJECT_NAME
project_app in INSTALLED_APPS or INSTALLED_APPS.insert(1,project_app)

#Import everything from local.settings
exec('from %s.local.settings import *' % PROJECT_NAME)